==> php81-nextcloud-28.0.2.tgz: share/nextcloud/apps/text/l10n/ja.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "新規のテキストファイル",
    "Create new text file" : "新規のテキストファイルを作成する",
    "The file was uploaded" : "ファイルがアップロードされました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードされたファイルがphp.iniのupload_max_filesizeディレクティブのサイズを超えています",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードされたファイルは、HTMLフォームで指定されたMAX_FILE_SIZEディレクティブ制限を超えています",
    "The file was only partially uploaded" : "ファイルは部分的にしかアップロードされていません",
    "No file was uploaded" : "ファイルがアップロードされていません",
    "Missing a temporary folder" : "一時保存フォルダーが見つかりません",
    "Could not write file to disk" : "ファイルをディスクに書き込めませんでした",
    "A PHP extension stopped the file upload" : "PHP拡張機能がファイルのアップロードを停止しました",
    "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "テキストドキュメント",
    "{user} has mentioned you in the text document {node}" : "{user} が、テキストファイル {} であなたに言及しました",
    "This file cannot be displayed as download is disabled by the share" : "このファイルは共有者によってダウンロードが制限されており、表示できません",
    "Readme" : "Readme",
    "Text" : "テキスト",
    "📝 Collaborative document editing" : "📝 共同文書編集",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "**📝共同文書編集！**\n\n- **📝 集中執筆：集中モードで、必要なフォーマットだけ。\n- **🙋 一緒に仕事をする：**友達や同僚と、Nextcloudを使っていようとなかろうと、共有して共同作業しよう！\n- **💾 オープンフォーマット:** ファイルは[Markdown](https://en.wikipedia.org/wiki/Markdown)として保存されるので、他のテキストアプリからも編集できます。\n- **✊ 強固な基盤：**私たちは[🦉 ProseMirror](https://prosemirror.net)をベースにした[🐈 tiptap](https://tiptap.scrumpy.io)を使用しています - 本当にありがとうございます！",
    "Nextcloud Assistant" : "Nextcloud アシスタント",
    "Translate" : "翻訳",
    "Show assistant results" : "アシスタントの結果を表示する",
    "Insert result" : "結果を挿入する",
    "Show result" : "結果を表示する",
    "Delete task" : "タスクを削除",
    "Nextcloud Assistant result copied" : "Nextcloud アシスタントの結果をコピーしました",
    "Could not copy result to clipboard" : "結果をコピーできませんでした",
    "Use current version" : "現在のバージョンを使用",
    "Use the saved version" : "保存済みのバージョンを使用",
    "Failed to load file" : "ファイルの読み込みに失敗しました",
    "Document idle for {timeout} minutes, click to continue editing" : "ドキュメントが{timeout}分間アイドル状態です。クリックして編集を続行します",
    "Reconnect" : "再接続",
    "The document has been changed outside of the editor. The changes cannot be applied." : "ドキュメントがエディターの外部から変更されました。変更点を適用できません。",
    "File could not be loaded. Please check your internet connection." : "ファイルを読み込めませんでした。 インターネット接続を確認してください。",
    "This file is opened read-only as it is currently locked by {user}." : "このファイルは現在 {user} によってロックされているため、読み取り専用で開かれました",
    "Close outline view" : "目次の表示を閉じる",
    "Outline" : "目次",
    "Enter your name so other people can see who is editing" : "編集中の人が誰なのか他のユーザに分かるように、名前を入力してください",
    "Edit guest name" : "ゲスト名を編集",
    "Guest" : "ゲスト",
    "Save guest name" : "ゲスト名を保存",
    "Insert an attachment" : "添付ファイルを挿入する",
    "guest" : "ゲスト",
    "Show author colors" : "記入者の色をつける",
    "Author colors are only shown until everyone has closed the document." : "記入者の色は、全員がドキュメントを閉じるまで表示されます。",
    "Active people" : "ファイルを開いているユーザー",
    "Save document" : "ファイルを保存する",
    "Last saved" : "最終保存",
    "Offline" : "オフライン",
    "Offline, changes will be saved when online" : "オフラインです。変更はオンラインになった時に保存されます",
    "Saving …" : "保存中 ...",
    "Saved" : "保存済み",
    "Last saved {lastSave}" : "最終保存 {lastSave}",
    "Unsaved changes" : "未保存の変更点",
    "Formatting help" : "書式設定のヘルプ",
    "Speed up your writing with simple shortcuts." : "シンプルなショートカットを使って文書作成をスピードアップ！",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "Markdown記法で入力するか、下に示すキーボードショートカットを使ってみましょう。",
    "Just type the Markdown syntax from below." : "Markdown記法で入力してみましょう。",
    "Style" : "書式",
    "Syntax" : "Markdown記法",
    "Keyboard shortcuts" : "キーボードショートカット",
    "New paragraph" : "新しい段落",
    "Enter" : "Enter",
    "Hard line break" : "強制的な改行",
    "followed by" : "に続けて",
    "Backspace" : "バックスペース",
    "Shift" : "Shift",
    "Bold" : "太字",
    "Bold text" : "太字",
    "Ctrl" : "Ctrl",
    "Italic" : "斜体",
    "Italicized text" : "斜体で書きたい文字",
    "Strikethrough" : "取り消し線",
    "Mistaken text" : "誤って書いた文字",
    "Underline" : "下線",
    "Underlined text" : "下線を引きたい文字",
    "Heading 1" : "見出し1",
    "Heading level 1" : "見出しレベル 1",
    "Heading 6" : "見出し6",
    "Heading level 6" : "見出しレベル 6",
    "Unordered list" : "番号なしの箇条書き",
    "An item" : "項目",
    "Ordered list" : "順序付きの箇条書き",
    "First item" : "1つ目の項目",
    "Checklist" : "チェックマーク付きの箇条書き",
    "To-Do item" : "To-Do 項目",
    "Blockquote" : "引用",
    "Quoted text" : "引用された文字",
    "Code block" : "コードブロック",
    "Some code" : "何かコード",
    "Edit link" : "リンクを編集",
    "Save changes" : "変更を保存",
    "Remove link" : "リンクを削除",
    "Cancel" : "キャンセル",
    "URL" : "URL",
    "Cannot copy, please copy the link manually" : "コピーできませんでした。手動でリンクをコピーしてください。",
    "Copy link to clipboard" : "リンクをクリップボードにコピーする",
    "Upload from computer" : "コンピュータからアップロード",
    "Insert from Files" : "アップロード済のファイルを挿入",
    "Link to file or folder" : "ファイルやフォルダーへのリンク",
    "Link to website" : "ウェブサイトへのリンク",
    "Update link" : "リンクの更新",
    "Open the Smart Picker" : "スマートピッカーを開く",
    "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
    "_%n word_::_%n words_" : ["%n語"],
    "_%n char_::_%n chars_" : ["%n文字"],
    "Editor actions" : "編集者のアクション",
    "Formatting menu bar" : "書式設定のメニューバー",
    "Remaining actions" : "残りのアクション",
    "To translate individual parts of the text, select it before using the translate function." : "文章の翻訳したい部分を選択してから、翻訳機能を使います。",
    "Translate from" : "原文の言語",
    "Select language" : "言語を選択する",
    "to" : "訳文の言語",
    "Replace" : "入れ替え",
    "Insert" : "挿入する",
    "Detect language" : "言語を検出する",
    "Translate from {language}" : "{language}から翻訳する",
    "Translate to {language}" : "{language}へ翻訳する",
    "Translation failed" : "翻訳に失敗しました",
    "No emoji found" : "絵文字が見つかりません",
    "No command found" : "コマンドが見つかりません",
    "No user found" : "ユーザーが見つかりません",
    "No suggestion found" : "提案が見つかりません",
    "Code block options" : "コードブロックの選択",
    "Code block language" : "コードブロックの言語",
    "e.g. php, javascript, json…" : "例えば php, javascript, json等･･･",
    "Source code" : "ソースコード",
    "Diagram" : "ダイアグラム",
    "Both" : "両方",
    "Mermaid documentation" : "Mermaid のドキュメント",
    "Link to this section" : "このセクションへのリンク",
    "Delete this attachment" : "この添付ファイルを削除する",
    "Delete this image" : "この画像を削除する",
    "Failed to load" : "読込に失敗しました",
    "Could not find image in attachments list." : "添付ファイルリストに画像が見つかりません。",
    "Add row before" : "行を上に追加する",
    "Add row after" : "行を下に追加する",
    "Delete this row" : "この行を削除する",
    "Left align column" : "この列を左寄せにする",
    "Center align column" : "この列を中央揃えにする",
    "Right align column" : "この列を右寄せにする",
    "Add column before" : "列を左に追加する",
    "Add column after" : "列を右に追加する",
    "Delete this column" : "この列を削除する",
    "Delete this table" : "この表を削除する",
    "Show folder description" : "フォルダーの概要を表示する",
    "Hide outline" : "目次を隠す",
    "Show outline" : "目次を表示する",
    "Undo" : "元に戻す",
    "Redo" : "やり直し",
    "Headings" : "見出し",
    "Heading 2" : "見出し2",
    "Heading 3" : "見出し3",
    "Heading 4" : "見出し4",
    "Heading 5" : "見出し5",
    "To-Do list" : "To-Do リスト",
    "Insert link" : "リンクを挿入する",
    "Callouts" : "コールアウト",
    "Info" : "情報",
    "Success" : "完了",
    "Warning" : "警告",
    "Danger" : "危険",
    "Table" : "表",
    "Insert emoji" : "絵文字を挿入",
    "Insert attachment" : "添付ファイルを挿入する",
    "Command" : "コマンド",
    "Control" : "コントロール",
    "Option" : "Option",
    "Formatting" : "フォーマット",
    "Smart picker" : "スマートピッカー",
    "Add notes, lists or links …" : "ノート、リスト、リンクを追加...",
    "Edit" : "編集",
    "Add description" : "説明を追加",
    "\"{name}\" already exist!" : "\"{name}\" は既に存在します",
    "Created \"{name}\"" : "\"{name}\" を作成しました",
    "Link copied" : "リンクをコピーしました",
    "Could not copy link to the clipboard:" : "クリップボードにリンクをコピーできませんでした:",
    "Front matter" : "Front matter",
    "Source language" : "原文の言語",
    "Target language" : "訳文の言語",
    "Unsupported image type" : "サポートされていない画像形式です",
    "Show rich workspaces" : "各フォルダのReadmeを表示",
    "e.g. php, javascript, json, ..." : "例えば php, javascript, json等･･･"
},
"nplurals=1; plural=0;");

==> php81-nextcloud-30.0.5.tgz: share/nextcloud/apps/text/l10n/ja.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "ファイルがアップロードされました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードされたファイルがphp.iniのupload_max_filesizeディレクティブのサイズを超えています",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードされたファイルは、HTMLフォームで指定されたMAX_FILE_SIZEディレクティブ制限を超えています",
    "The file was only partially uploaded" : "ファイルは部分的にしかアップロードされていません",
    "No file was uploaded" : "ファイルがアップロードされていません",
    "Missing a temporary folder" : "一時保存フォルダーが見つかりません",
    "Could not write file to disk" : "ファイルをディスクに書き込めませんでした",
    "A PHP extension stopped the file upload" : "PHP拡張機能がファイルのアップロードを停止しました",
    "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "テキストドキュメント",
    "New text file" : "新規のテキストファイル",
    "Create new text file" : "新規のテキストファイルを作成する",
    "Editing session has expired. Please reload the page." : "編集セッションの有効期限が切れました。ページを再読み込みしてください。",
    "{user} has mentioned you in the text document {node}" : "{user} が、テキストファイル {} であなたに言及しました",
    "This file cannot be displayed as download is disabled by the share" : "このファイルは共有者によってダウンロードが制限されており、表示できません",
    "File not found" : "ファイルが見つかりません",
    "Readme" : "Readme",
    "Text" : "テキスト",
    "📝 Collaborative document editing" : "📝 共同文書編集",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "**📝共同文書編集！**\n\n- **📝 集中執筆：集中モードで、必要なフォーマットだけ。\n- **🙋 一緒に仕事をする：**友達や同僚と、Nextcloudを使っていようとなかろうと、共有して共同作業しよう！\n- **💾 オープンフォーマット:** ファイルは[Markdown](https://en.wikipedia.org/wiki/Markdown)として保存されるので、他のテキストアプリからも編集できます。\n- **✊ 強固な基盤：**私たちは[🦉 ProseMirror](https://prosemirror.net)をベースにした[🐈 tiptap](https://tiptap.scrumpy.io)を使用しています - 本当にありがとうございます！",
    "Nextcloud Assistant" : "Nextcloud アシスタント",
    "Translate" : "翻訳",
    "Show assistant results" : "アシスタントの結果を表示する",
    "Assistant results" : "アシスタントの結果",
    "Insert result" : "結果を挿入する",
    "Show result" : "結果を表示する",
    "Delete task" : "タスクを削除",
    "Nextcloud Assistant result copied" : "Nextcloud アシスタントの結果をコピーしました",
    "Could not copy result to clipboard" : "結果をコピーできませんでした",
    "Use current version" : "現在のバージョンを使用",
    "Use the saved version" : "保存済みのバージョンを使用",
    "Reload" : "再読み込み",
    "Document has been changed outside of the editor. The changes cannot be applied" : "ドキュメントがエディター外で変更されました。変更を適用できません",
    "Document could not be loaded. Please check your internet connection." : "ドキュメントを読み込めませんでした。インターネット接続を確認してください。",
    "Reconnect" : "再接続",
    "Document idle for {timeout} minutes, click to continue editing" : "ドキュメントが{timeout}分間アイドル状態です。クリックして編集を続行します",
    "This file is opened read-only as it is currently locked by {user}." : "このファイルは現在 {user} によってロックされているため、読み取り専用で開かれました",
    "Close outline view" : "目次の表示を閉じる",
    "Outline" : "目次",
    "Enter your name so other people can see who is editing" : "編集中の人が誰なのか他のユーザに分かるように、名前を入力してください",
    "Edit guest name" : "ゲスト名を編集",
    "Guest" : "ゲスト",
    "Save guest name" : "ゲスト名を保存",
    "Uploading multiple attachments failed." : "複数の添付ファイルのアップロードに失敗しました。",
    "Uploading attachment failed: {error}" : "添付ファイルのアップロードに失敗しました: {error}",
    "Uploading attachment failed." : "添付ファイルのアップロードに失敗しました。",
    "Insert an attachment" : "添付ファイルを挿入する",
    "Failed to insert from Files" : "ファイルからの挿入に失敗しました",
    "Preview options" : "プレビューオプション",
    "Text only" : "テキストのみ",
    "Show link preview" : "リンクのプレビューを表示",
    "Remove link" : "リンクを削除",
    "guest" : "ゲスト",
    "Full width editor" : "フルワイドエディタ",
    "Active people" : "ファイルを開いているユーザー",
    "Save document" : "ファイルを保存する",
    "Last saved" : "最終保存",
    "Offline" : "オフライン",
    "Offline, changes will be saved when online" : "オフラインです。変更はオンラインになった時に保存されます",
    "Saving …" : "保存中 ...",
    "Saved" : "保存済み",
    "Last saved {lastSave}" : "最終保存 {lastSave}",
    "The document has been changed outside of the editor. The changes cannot be applied." : "ドキュメントがエディターの外部から変更されました。変更点を適用できません。",
    "Unsaved changes" : "未保存の変更点",
    "Connection failed." : "接続に失敗しました。",
    "Formatting and shortcuts" : "書式とショートカット",
    "Speed up your writing with simple shortcuts." : "シンプルなショートカットを使って文書作成をスピードアップ！",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "Markdown記法で入力するか、下に示すキーボードショートカットを使ってみましょう。",
    "Just type the Markdown syntax from below." : "Markdown記法で入力してみましょう。",
    "Style" : "書式",
    "Syntax" : "Markdown記法",
    "Keyboard shortcuts" : "キーボードショートカット",
    "New paragraph" : "新しい段落",
    "Enter" : "Enter",
    "Hard line break" : "強制的な改行",
    "followed by" : "に続けて",
    "Backspace" : "バックスペース",
    "Shift" : "Shift",
    "Bold" : "太字",
    "Bold text" : "太字",
    "Ctrl" : "Ctrl",
    "Italic" : "斜体",
    "Italicized text" : "斜体で書きたい文字",
    "Strikethrough" : "取り消し線",
    "Mistaken text" : "誤って書いた文字",
    "Underline" : "下線",
    "Underlined text" : "下線を引きたい文字",
    "Heading 1" : "見出し1",
    "Heading level 1" : "見出しレベル 1",
    "Heading 6" : "見出し6",
    "Heading level 6" : "見出しレベル 6",
    "Unordered list" : "番号なしの箇条書き",
    "An item" : "項目",
    "Ordered list" : "順序付きの箇条書き",
    "First item" : "1つ目の項目",
    "Checklist" : "チェックマーク付きの箇条書き",
    "To-Do item" : "To-Do 項目",
    "Blockquote" : "引用",
    "Quoted text" : "引用された文字",
    "Code block" : "コードブロック",
    "Some code" : "何かコード",
    "Link" : "リンク",
    "Insert emoji" : "絵文字を挿入",
    "emoji" : "絵文字",
    "Mention someone" : "誰かにメンション",
    "name" : "名前",
    "Smart picker" : "スマートピッカー",
    "something" : "何か",
    "Action" : "アクション",
    "Undo" : "元に戻す",
    "Redo" : "やり直し",
    "Toggle outline" : "アウトラインを切り替える",
    "Alt" : "Alt",
    "Edit link" : "リンクを編集",
    "Save changes" : "変更を保存",
    "Cancel" : "キャンセル",
    "URL" : "URL",
    "Cannot copy, please copy the link manually" : "コピーできませんでした。手動でリンクをコピーしてください。",
    "Copy link to clipboard" : "リンクをクリップボードにコピーする",
    "Upload from computer" : "コンピュータからアップロード",
    "Insert from Files" : "アップロード済のファイルを挿入",
    "Formatting help" : "書式設定のヘルプ",
    "Link to file or folder" : "ファイルやフォルダーへのリンク",
    "Link to website" : "ウェブサイトへのリンク",
    "Update link" : "リンクの更新",
    "Open the Smart Picker" : "スマートピッカーを開く",
    "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\" が選択されました",
    "_%n word_::_%n words_" : ["%n語"],
    "_%n char_::_%n chars_" : ["%n文字"],
    "Editor actions" : "編集者のアクション",
    "Formatting menu bar" : "書式設定のメニューバー",
    "Remaining actions" : "残りのアクション",
    "To translate individual parts of the text, select it before using the translate function." : "文章の翻訳したい部分を選択してから、翻訳機能を使います。",
    "Translate from" : "原文の言語",
    "Select language" : "言語を選択する",
    "Text to translate from" : "翻訳元テキスト",
    "to" : "訳文の言語",
    "Translate to" : "翻訳先",
    "Translated text result" : "テキスト翻訳の結果",
    "Replace" : "入れ替え",
    "Insert" : "挿入する",
    "Detect language" : "言語を検出する",
    "Translate from {language}" : "{language}から翻訳する",
    "Translate to {language}" : "{language}へ翻訳する",
    "Translation failed" : "翻訳に失敗しました",
    "No emoji found" : "絵文字が見つかりません",
    "No command found" : "コマンドが見つかりません",
    "No user found" : "ユーザーが見つかりません",
    "No suggestion found" : "提案が見つかりません",
    "Edit" : "編集",
    "Copy code block" : "コードブロックをコピー",
    "Copy code" : "コピーコード",
    "Code block options" : "コードブロックの選択",
    "Code block language" : "コードブロックの言語",
    "e.g. php, javascript, json…" : "例えば php, javascript, json等･･･",
    "Source code" : "ソースコード",
    "Diagram" : "ダイアグラム",
    "Both" : "両方",
    "Mermaid documentation" : "Mermaid のドキュメント",
    "Delete this attachment" : "この添付ファイルを削除する",
    "Delete this image" : "この画像を削除する",
    "Failed to load" : "読込に失敗しました",
    "Could not find image in attachments list." : "添付ファイルリストに画像が見つかりません。",
    "Add row before" : "行を上に追加する",
    "Add row after" : "行を下に追加する",
    "Delete this row" : "この行を削除する",
    "Left align column" : "この列を左寄せにする",
    "Center align column" : "この列を中央揃えにする",
    "Right align column" : "この列を右寄せにする",
    "Add column before" : "列を左に追加する",
    "Add column after" : "列を右に追加する",
    "Delete this column" : "この列を削除する",
    "Delete this table" : "この表を削除する",
    "Add row below" : "行を下に追加する",
    "Show folder description" : "フォルダーの概要を表示する",
    "Hide outline" : "目次を隠す",
    "Show outline" : "目次を表示する",
    "Done" : "完了",
    "Headings" : "見出し",
    "Heading 2" : "見出し2",
    "Heading 3" : "見出し3",
    "Heading 4" : "見出し4",
    "Heading 5" : "見出し5",
    "Lists" : "リスト",
    "To-Do list" : "To-Do リスト",
    "Increase indentation" : "インデントを増やす",
    "Decrease indentation" : "インデントを減らす",
    "Blocks" : "ブロック",
    "Info callout" : "情報コールアウト",
    "Success callout" : "成功コールアウト",
    "Warning callout" : "警告コールアウト",
    "Danger callout" : "危険コールアウト",
    "Table" : "表",
    "Details" : "詳細",
    "Insert link" : "リンクを挿入する",
    "Insert attachment" : "添付ファイルを挿入する",
    "Command" : "コマンド",
    "Control" : "コントロール",
    "Option" : "Option",
    "Formatting" : "フォーマット",
    "Start writing, or try '/' to add, '@' to mention…" : "書き始めるか、「/」で追加、「@」でメンション...。",
    "Add folder description" : "フォルダーの説明を追加",
    "\"{name}\" already exist!" : "\"{name}\" は既に存在します",
    "Created \"{name}\"" : "\"{name}\" を作成しました",
    "Copied to the clipboard" : "クリップボードにコピーされました",
    "Could not copy to the clipboard" : "クリップボードにコピーできませんでした",
    "Front matter" : "Front matter",
    "Link to this section" : "このセクションへのリンク",
    "Show author colors" : "記入者の色をつける",
    "Author colors are only shown until everyone has closed the document." : "記入者の色は、全員がドキュメントを閉じるまで表示されます。",
    "Callouts" : "コールアウト",
    "Info" : "情報",
    "Success" : "完了",
    "Warning" : "警告",
    "Danger" : "危険",
    "Add notes, lists or links …" : "ノート、リスト、リンクを追加...",
    "Add description" : "説明を追加"
},
"nplurals=1; plural=0;");
